'use strict';

class ParticleManager {
    constructor(renderer) {
        this._renderer = renderer;

        this._particles = new Set();
    }

    createParticle(spriteId, lifetime, x, y, velocityX = 0.0, velocityY = 0.0, scaleX = 1.0, scaleY = 1.0, scaleXChange = 0.0, scaleYChange = 0.0, rotation = 0.0, angularVelocity = 0.0) {
        this._particles.add({
            spriteId: spriteId,
            lifetime: lifetime,
            x: x,
            y: y,
            velocityX: velocityX,
            velocityY: velocityY,
            scaleX: scaleX,
            scaleY: scaleY,
            scaleXChange: scaleXChange,
            scaleYChange: scaleYChange,
            rotation: rotation,
            angularVelocity: angularVelocity,
        });
    }

    update(elapsedSeconds) {
        this._particles.forEach((particle) => {
            particle.lifetime -= elapsedSeconds;
            if (particle.lifetime <= 0) {
                this._particles.delete(particle);
                return;
            }
            particle.x += particle.velocityX * elapsedSeconds;
            particle.y += particle.velocityY * elapsedSeconds;
            particle.scaleX += particle.scaleXChange * elapsedSeconds;
            particle.scaleY += particle.scaleYChange * elapsedSeconds;
            particle.rotation += particle.angularVelocity * elapsedSeconds;
            this._renderer.drawSprite(particle.spriteId, particle.x, particle.y, particle.scaleX, particle.scaleY, particle.rotation);
        });
    }
}
